@@ -1,23 +1,18 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 import sys
 
-import django
+from django.core.management.base import LabelCommand
 from django.template import TemplateDoesNotExist, loader
 
 from django_extensions.management.utils import signalcommand
-from django_extensions.compat import CompatibilityLabelCommand as LabelCommand
 
 
 def get_template_path(path):
     try:
-        if django.VERSION < (1, 8):
-            template = loader.find_template(path)[1]
-        else:
-            template = loader.get_template(path).template
-
+        template = loader.get_template(path).template
         if template:
             return template.name
-        # work arround https://code.djangoproject.com/ticket/17199 issue
+        # work around https://code.djangoproject.com/ticket/17199 issue
         for template_loader in loader.template_source_loaders:
             try:
                 source, origin = template_loader.load_template_source(path)
