@@ -1,12 +1,11 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 import sys
 import json
 
 import six
 from django.conf import settings
-from django.core.management.base import CommandError
+from django.core.management.base import BaseCommand, CommandError
 
-from django_extensions.compat import CompatibilityBaseCommand as BaseCommand
 from django_extensions.management.modelviz import generate_graph_data, generate_dot
 from django_extensions.management.utils import signalcommand
 
@@ -17,16 +16,17 @@ except ImportError:
     HAS_PYGRAPHVIZ = False
 
 try:
-    import pydot
+    try:
+        import pydotplus as pydot
+    except ImportError:
+        import pydot
     HAS_PYDOT = True
 except ImportError:
     HAS_PYDOT = False
 
 
 class Command(BaseCommand):
-    help = "Creates a GraphViz dot file for the specified app names.  You can pass multiple app names and they will all be combined into a single model.  Output is usually directed to a dot file."
-    args = "[appname]"
-    label = 'application name'
+    help = "Creates a GraphViz dot file for the specified app names. You can pass multiple app names and they will all be combined into a single model. Output is usually directed to a dot file."
 
     can_import_settings = True
 
@@ -45,7 +45,7 @@ class Command(BaseCommand):
                 'help': 'Use PyGraphViz to generate the image.'},
 
             '--pydot': {'action': 'store_true', 'dest': 'pydot',
-                        'help': 'Use PyDot to generate the image.'},
+                        'help': 'Use PyDot(Plus) to generate the image.'},
 
             '--disable-fields -d': {
                 'action': 'store_true', 'dest': 'disable_fields',
@@ -128,12 +128,14 @@ class Command(BaseCommand):
 
     def add_arguments(self, parser):
         """Unpack self.arguments for parser.add_arguments."""
+        parser.add_argument('app_label', nargs='*')
         for argument in self.arguments:
             parser.add_argument(*argument.split(' '),
                                 **self.arguments[argument])
 
     @signalcommand
     def handle(self, *args, **options):
+        args = options['app_label']
         if len(args) < 1 and not options['all_applications']:
             raise CommandError("need one or more arguments for appname")
 
@@ -163,7 +165,7 @@ class Command(BaseCommand):
             elif use_pydot:
                 self.render_output_pydot(dotdata, **options)
             else:
-                raise CommandError("Neither pygraphviz nor pydot could be found to generate the image")
+                raise CommandError("Neither pygraphviz nor pydotplus could be found to generate the image")
         else:
             self.print_output(dotdata)
 
