@@ -1,4 +1,4 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 import os
 import six
 import sys
@@ -6,12 +6,12 @@ import time
 import traceback
 
 from django.conf import settings
-from django.core.management.base import CommandError
+from django.core.management.base import BaseCommand, CommandError
+from django.db.backends import utils
+from django.utils.six import PY3
 
-from django_extensions.compat import PY3
 from django_extensions.management.shells import import_objects
 from django_extensions.management.utils import signalcommand
-from django_extensions.compat import CompatibilityBaseCommand as BaseCommand
 
 
 def use_vi_mode():
@@ -26,6 +26,7 @@ class Command(BaseCommand):
     help = "Like the 'shell' command but autoloads the models of all installed Django apps."
 
     def add_arguments(self, parser):
+        super(Command, self).add_arguments(parser)
         parser.add_argument(
             '--plain', action='store_true', dest='plain',
             help='Tells Django to use plain Python, not BPython nor IPython.')
@@ -47,6 +48,8 @@ class Command(BaseCommand):
         parser.add_argument(
             '--kernel', action='store_true', dest='kernel',
             help='Tells Django to start an IPython Kernel.')
+        parser.add_argument('--connection-file', action='store', dest='connection_file',
+                    help='Specifies the connection file to use if using the --kernel option'),
         parser.add_argument(
             '--use-pythonrc', action='store_true', dest='use_pythonrc',
             help='Tells Django to execute PYTHONSTARTUP file '
@@ -69,6 +72,12 @@ class Command(BaseCommand):
             dest='no_browser',
             help='Don\'t open the notebook in a browser after startup.')
 
+    def get_ipython_arguments(self, options):
+        return getattr(settings, 'IPYTHON_ARGUMENTS', [])
+
+    def get_notebook_arguments(self, options):
+        return getattr(settings, 'NOTEBOOK_ARGUMENTS', [])
+
     @signalcommand
     def handle(self, *args, **options):
         use_kernel = options.get('kernel', False)
@@ -81,16 +90,11 @@ class Command(BaseCommand):
         use_pythonrc = options.get('use_pythonrc', True)
         no_browser = options.get('no_browser', False)
         verbosity = int(options.get('verbosity', 1))
+        print_sql = getattr(settings, 'SHELL_PLUS_PRINT_SQL', False)
+
+        if options.get("print_sql", False) or print_sql:
 
-        if options.get("print_sql", False):
             # Code from http://gist.github.com/118990
-            try:
-                # Django 1.7 onwards
-                from django.db.backends import utils
-            except ImportError:
-                # Django 1.6 and below
-                from django.db.backends import util as utils
-
             sqlparse = None
             try:
                 import sqlparse
@@ -121,13 +125,20 @@ class Command(BaseCommand):
                 if release.version_info[0] < 2:
                     print(self.style.ERROR("--kernel requires at least IPython version 2.0"))
                     return
-                from IPython import embed_kernel
+                from IPython import start_kernel
             except ImportError:
                 return traceback.format_exc()
 
             def run_kernel():
                 imported_objects = import_objects(options, self.style)
-                embed_kernel(local_ns=imported_objects)
+                kwargs = dict(
+                    argv=[],
+                    user_ns=imported_objects,
+                )
+                connection_file = options.get('connection_file')
+                if connection_file:
+                    kwargs['connection_file'] = connection_file
+                start_kernel(**kwargs)
             return run_kernel
 
         def get_notebook():
@@ -187,12 +198,12 @@ class Command(BaseCommand):
                 app = NotebookApp.instance()
 
                 # Treat IPYTHON_ARGUMENTS from settings
-                ipython_arguments = getattr(settings, 'IPYTHON_ARGUMENTS', [])
+                ipython_arguments = self.get_ipython_arguments(options)
                 if 'django_extensions.management.notebook_extension' not in ipython_arguments:
                     ipython_arguments.extend(['--ext', 'django_extensions.management.notebook_extension'])
 
                 # Treat NOTEBOOK_ARGUMENTS from settings
-                notebook_arguments = getattr(settings, 'NOTEBOOK_ARGUMENTS', [])
+                notebook_arguments = self.get_notebook_arguments(options)
                 if no_browser and '--no-browser' not in notebook_arguments:
                     notebook_arguments.append('--no-browser')
                 if '--notebook-dir' not in notebook_arguments:
@@ -267,7 +278,7 @@ class Command(BaseCommand):
 
                 def run_ipython():
                     imported_objects = import_objects(options, self.style)
-                    ipython_arguments = getattr(settings, 'IPYTHON_ARGUMENTS', [])
+                    ipython_arguments = self.get_ipython_arguments(options)
                     start_ipython(argv=ipython_arguments, user_ns=imported_objects)
                 return run_ipython
             except ImportError:
