@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 sqldiff.py - Prints the (approximated) difference between models and database
 
@@ -20,27 +21,19 @@ KNOWN ISSUES:
      positives or false negatives.
 """
 
+import importlib
 import sys
-from optparse import make_option
 
-import django
 import six
-from django.core.management import CommandError, sql as _sql
-from django.core.management.base import BaseCommand
+from django.apps import apps
+from django.core.management import BaseCommand, CommandError, sql as _sql
+from django.core.management.base import OutputWrapper
 from django.core.management.color import no_style
 from django.db import connection, transaction
 from django.db.models.fields import AutoField, IntegerField
 
-from django_extensions.compat import get_app_models
 from django_extensions.management.utils import signalcommand
 
-try:
-    from django.core.management.base import OutputWrapper
-    HAS_OUTPUTWRAPPER = True
-except ImportError:
-    HAS_OUTPUTWRAPPER = False
-
-
 ORDERING_FIELD = IntegerField('_order', null=True)
 
 
@@ -79,7 +72,6 @@ class SQLDiff(object):
 
     IGNORE_MISSING_TABLES = [
         "django_migrations",
-        "south_migrationhistory",
     ]
 
     DIFF_TYPES = [
@@ -152,10 +144,8 @@ class SQLDiff(object):
 
         self.cursor = connection.cursor()
         self.django_tables = self.get_django_tables(options.get('only_existing', True))
-        self.db_tables = self.introspection.get_table_list(self.cursor)
-        if django.VERSION[:2] >= (1, 8):
-            # TODO: We are losing information about tables which are views here
-            self.db_tables = [table_info.name for table_info in self.db_tables]
+        # TODO: We are losing information about tables which are views here
+        self.db_tables = [table_info.name for table_info in self.introspection.get_table_list(self.cursor)]
         self.differences = []
         self.unknown_db_fields = {}
         self.new_db_fields = set()
@@ -233,7 +223,7 @@ class SQLDiff(object):
     def get_field_db_type(self, description, field=None, table_name=None):
         from django.db import models
         # DB-API cursor.description
-        #(name, type_code, display_size, internal_size, precision, scale, null_ok) = description
+        # (name, type_code, display_size, internal_size, precision, scale, null_ok) = description
         type_code = description[1]
         if type_code in self.DATA_TYPES_REVERSE_OVERRIDE:
             reverse_type = self.DATA_TYPES_REVERSE_OVERRIDE[type_code]
@@ -278,7 +268,6 @@ class SQLDiff(object):
             kwargs['geography'] = True
 
         if '.' in reverse_type:
-            from django_extensions.compat import importlib
             module_path, package_name = reverse_type.rsplit('.', 1)
             module = importlib.import_module(module_path)
             field_db_type = getattr(module, package_name)(**kwargs).db_type(connection=connection)
@@ -422,20 +411,14 @@ class SQLDiff(object):
             if func:
                 model_type, db_type = func(field, description, model_type, db_type)
 
-            if django.VERSION[:2] >= (1, 7):
-                # Django >=1.7
-                model_check = field.db_parameters(connection=connection)['check']
-                if ' CHECK' in db_type:
-                    db_type, db_check = db_type.split(" CHECK", 1)
-                    db_check = db_check.strip().lstrip("(").rstrip(")")
-                else:
-                    db_check = None
-                if not model_type == db_type and not model_check == db_check:
-                    self.add_difference('field-parameter-differ', table_name, field.name, model_type, db_type)
+            model_check = field.db_parameters(connection=connection)['check']
+            if ' CHECK' in db_type:
+                db_type, db_check = db_type.split(" CHECK", 1)
+                db_check = db_check.strip().lstrip("(").rstrip(")")
             else:
-                # Django <1.7
-                if not model_type == db_type:
-                    self.add_difference('field-parameter-differ', table_name, field.name, model_type, db_type)
+                db_check = None
+            if not model_type == db_type and not model_check == db_check:
+                self.add_difference('field-parameter-differ', table_name, field.name, model_type, db_type)
 
     def find_field_notnull_differ(self, meta, table_description, table_name):
         if not self.can_detect_notnull_differ:
@@ -598,10 +581,6 @@ class MySQLDiff(SQLDiff):
         super(MySQLDiff, self).__init__(app_models, options)
         self.auto_increment = set()
         self.load_auto_increment()
-        if not getattr(connection.features, 'can_introspect_small_integer_field', False):
-            from MySQLdb.constants import FIELD_TYPE
-            # Django version < 1.8 does not support MySQL small integer introspection, adding override.
-            self.DATA_TYPES_REVERSE_OVERRIDE[FIELD_TYPE.SHORT] = 'SmallIntegerField'
 
     def load_null(self):
         tablespace = 'public'
@@ -906,17 +885,6 @@ DATABASE_SQLDIFF_CLASSES = {
 
 
 class Command(BaseCommand):
-    option_list = BaseCommand.option_list + (
-        make_option('--all-applications', '-a', action='store_true', dest='all_applications',
-                    help="Automaticly include all application from INSTALLED_APPS."),
-        make_option('--not-only-existing', '-e', action='store_false', dest='only_existing',
-                    help="Check all tables that exist in the database, not only tables that should exist based on models."),
-        make_option('--dense-output', '-d', action='store_true', dest='dense_output',
-                    help="Shows the output in dense format, normally output is spreaded over multiple lines."),
-        make_option('--output_text', '-t', action='store_false', dest='sql', default=True,
-                    help="Outputs the differences as descriptive text instead of SQL"),
-    )
-
     help = """Prints the (approximated) difference between models and fields in the database for the given app name(s).
 
 It indicates how columns in the database are different from the sql that would
@@ -925,16 +893,37 @@ it can certainly help) It's purpose is to show the current differences as a way
 to check/debug ur models compared to the real database tables and columns."""
 
     output_transaction = False
-    args = '<appname appname ...>'
+
+    def add_arguments(self, parser):
+        super(Command, self).add_arguments(parser)
+        parser.add_argument('app_label', nargs='*')
+        parser.add_argument(
+            '--all-applications', '-a', action='store_true',
+            dest='all_applications',
+            help="Automaticly include all application from INSTALLED_APPS.")
+        parser.add_argument(
+            '--not-only-existing', '-e', action='store_false',
+            dest='only_existing',
+            help="Check all tables that exist in the database, not only "
+            "tables that should exist based on models.")
+        parser.add_argument(
+            '--dense-output', '-d', action='store_true', dest='dense_output',
+            help="Shows the output in dense format, normally output is "
+            "spreaded over multiple lines.")
+        parser.add_argument(
+            '--output_text', '-t', action='store_false', dest='sql',
+            default=True,
+            help="Outputs the differences as descriptive text instead of SQL")
 
     def __init__(self, *args, **kwargs):
         super(Command, self).__init__(*args, **kwargs)
         self.exit_code = 1
 
     @signalcommand
-    def handle(self, *app_labels, **options):
+    def handle(self, *args, **options):
         from django.conf import settings
 
+        app_labels = options.get('app_label')
         engine = None
         if hasattr(settings, 'DATABASES'):
             engine = settings.DATABASES['default']['ENGINE']
@@ -949,15 +938,18 @@ because you haven't specified the DATABASE_ENGINE setting.
 Edit your settings file and change DATABASE_ENGINE to something like 'postgresql' or 'mysql'.""")
 
         if options.get('all_applications', False):
-            app_models = get_app_models()
+            app_models = apps.get_models(include_auto_created=True)
         else:
             if not app_labels:
                 raise CommandError('Enter at least one appname.')
 
-            app_models = get_app_models(app_labels)
+            if not isinstance(app_labels, (list, tuple, set)):
+                app_labels = [app_labels]
 
-        # remove all models that are not managed by Django
-        #app_models = [model for model in app_models if getattr(model._meta, 'managed', True)]
+            app_models = []
+            for app_label in app_labels:
+                app_config = apps.get_app_config(app_label)
+                app_models.extend(app_config.get_models(include_auto_created=True))
 
         if not app_models:
             raise CommandError('Unable to execute sqldiff no models founds.')
@@ -985,10 +977,7 @@ Edit your settings file and change DATABASE_ENGINE to something like 'postgresql
             # self.stderr is not guaranteed to be set here
             stderr = getattr(self, 'stderr', None)
             if not stderr:
-                if HAS_OUTPUTWRAPPER:
-                    stderr = OutputWrapper(sys.stderr, self.style.ERROR)
-                else:
-                    stderr = sys.stderr
+                stderr = OutputWrapper(sys.stderr, self.style.ERROR)
             stderr.write('%s: %s' % (e.__class__.__name__, e))
             sys.exit(2)
 
