@@ -1,19 +1,14 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 import six
+from django.utils.encoding import force_text
 from django.utils.functional import allow_lazy
 
-# conditional import, force_unicode was renamed in Django 1.5
-try:
-    from django.utils.encoding import force_unicode  # NOQA
-except ImportError:
-    from django.utils.encoding import force_text as force_unicode  # NOQA
-
 
 def truncate_letters(s, num):
     """
     truncates a string to a number of letters, similar to truncate_words
     """
-    s = force_unicode(s)
+    s = force_text(s)
     length = int(num)
     if len(s) > length:
         s = s[:length]
